@@ -1,31 +1,5 @@
 # Loading/Cleaning/Describing Data ------------------------------------------------------------------------
 
-#' Treat gaze data outside of all AOIs as missing
-#'
-#' Should gaze outside of any AOI be considered trackloss? 
-#'
-#' @param data The data
-#' @param data_options The data options
-#' @return Data with correct AOIs
-
-.convert_non_aoi_to_missing <- function(data, data_options) {
-  
-  # Create version of AOIs with no NAs:
-  .narepl <- function(x) ifelse(is.na(x), 0, x)
-  data_no_na <- mutate_each_(data, funs(.narepl), vars = sapply(data_options$aoi_columns, as.name))
-  
-  # Find all rows which have no AOIs in them:
-  data_no_na[[".AOISum"]] <- 0
-  for (aoi in data_options$aoi_columns) {
-    data_no_na[[".AOISum"]] <- data_no_na[[".AOISum"]] + data_no_na[[aoi]]
-  }
-
-  # Set these rows as trackloss:
-  data[[data_options$trackloss_column]] <- ifelse(data_no_na[[".AOISum"]] == 0, TRUE, data_no_na[[data_options$trackloss_column]])
-  
-  return(data)
-}
-
 #' Convert raw data for use in eyetrackingR
 #' 
 #' This should be the first function you use when using eyetrackingR for a project (potentially with
@@ -52,7 +26,7 @@
 #' @param item_columns       Column names indicating items (optional)
 #' @param aoi_columns        Names of AOIs
 #' @param treat_non_aoi_looks_as_missing This is a logical indicating how you would like to perform
-#'   "proportion-looking" calculations, which are critical to any eyetracking analysis. If set to
+#'   "proportion-looking" calculations, which are central to eyetrackingR's eyetracking analyses. If set to
 #'   TRUE, any samples that are not in any of the AOIs (defined with the \code{aoi_columns} 
 #'   argument) are treated as missing data; when it comes time for eyetrackingR to calculate 
 #'   proportion looking to an AOI, this will be calculated as "time looking to that AOI divided by 
@@ -91,7 +65,7 @@ make_eyetrackingr_data <- function(data,
       return(FALSE)
     } else {
       stop("One of your columns (", col, ") could not be converted to the correct format (TRUE/FALSE), ",
-           "please do so manually.")
+           "please do so manually.", call. = FALSE)
     }
   }
   check_then_convert <- function(x, checkfunc, convertfunc, colname) {
@@ -100,8 +74,8 @@ make_eyetrackingr_data <- function(data,
       x <- convertfunc(x)
     } 
     if (colname=="Trackloss" & any(is.na(x))) {
-      warning("Found NAs in trackloss column, these will be treated as TRACKLOSS=FALSE.")
-      x <- ifelse(is.na(x), FALSE, x)
+      warning("Found NAs in trackloss column, these will be treated as TRACKLOSS=FALSE.", immediate. = TRUE, call. = FALSE)
+      x <- if_else(is.na(x), FALSE, x)
     }
     return(x)
   }
@@ -145,24 +119,22 @@ make_eyetrackingr_data <- function(data,
   
   ## Deal with Non-AOI looks:
   if (treat_non_aoi_looks_as_missing) {
-    out <- .convert_non_aoi_to_missing(out, data_options)
+    any_aoi <- rowSums(as.matrix(out[,data_options$aoi_columns,drop=FALSE]), na.rm = TRUE) > 0
+    out[[data_options$trackloss_column]][!any_aoi] <- TRUE
   }
   
   ## Set All AOI rows with trackloss to NA:
   # this ensures that any calculations of proportion-looking will not include trackloss in the denominator
   for (aoi in data_options$aoi_columns) {
-    out[[aoi]] <- ifelse(out[[data_options$trackloss_column]], NA, out[[aoi]])
-    # TO DO: check if any NAs in non-trackloss rows? that is, trackloss col should exactly track is.na() for all AOIs
+    out[[aoi]][ out[[data_options$trackloss_column]] ] <- NA
   }
   
   # Check for duplicate values of Trial column within Participants
   duplicates <- out %>%
-                group_by_(.dots = list(data_options$participant_column,
-                                       data_options$trial_column,
-                                       data_options$time_column)) %>%
-                summarise(count = n()) %>%
-                ungroup() %>%
-                filter(count > 1)
+    group_by_at(.vars = c(data_options$participant_column, data_options$trial_column, data_options$time_column) ) %>%
+    count() %>%
+    ungroup() %>%
+    filter(n > 1)
   
   if (nrow(duplicates) > 0) {
     print(duplicates)
@@ -174,7 +146,9 @@ make_eyetrackingr_data <- function(data,
   }
   
   ## Assign attribute:
-  class(out) <- c("eyetrackingR", "data.frame")
+  out <- arrange_at(.tbl = out, .vars = c(participant_column, trial_column, time_column))
+  out <- as_data_frame(out)
+  class(out) <- c("eyetrackingR_data", "eyetrackingR_df", class(out))
   attr(out, "eyetrackingR") <- list(data_options = data_options)
   return(out)
   
@@ -232,8 +206,30 @@ add_aoi <- function(data, aoi_dataframe,
     )
   }
   
+  stopifnot(all(c(x_col,y_col) %in% colnames(data)))
+  stopifnot(all(c(x_min_col,x_max_col, y_min_col, y_max_col) %in% colnames(aoi_dataframe)))
+  
+  if (x_col %in% c(x_min_col, x_max_col))
+    stop("The name of `x_col` cannot be the same as the name of `x_min_col` or `x_max_col`.")
+  if (y_col %in% c(y_min_col, y_max_col))
+    stop("The name of `y_col` cannot be the same as the name of `y_min_col` or `y_max_col`.")
+  
+  
   ## Join AOI info to dataset
-  df_joined <- left_join(data, aoi_dataframe)
+  if (any(colnames(data) %in% colnames(aoi_dataframe))) {
+    df_joined <- left_join(data, aoi_dataframe)
+  } else {
+    if (nrow(aoi_dataframe) > 1) {
+      stop("Your `aoi_dataframe` has more than one row, but it doesn't have any columns that match the columns in your data, so it's not clear how to map these rows onto this data.")
+    } else {
+
+      df_joined <- data
+      for (aoi_col in colnames(aoi_dataframe)) {
+        df_joined[[aoi_col]] <- aoi_dataframe[[aoi_col]]
+      }
+      
+    }
+  }
   
   ## Make AOI column
   message("Making ", aoi_name, " AOI...")
@@ -337,7 +333,8 @@ subset_by_window <- function(data,
       warning("The message ", msg, 
               " does not appear *exactly* one time for participant '", ppt_vec[1], 
               "' on trial '", trial_vec[1], "'. Trial will be removed from dataset.")
-      return(Inf) # not returning NA due to bug (at time of writing) in dplyr
+      if (is.integer(time_vec)) return(NA_integer_)
+      else return(NA_real_)
     }
     return(time_vec[bool])
   }
@@ -345,20 +342,18 @@ subset_by_window <- function(data,
   # Prelims:
   orig_classes <- class(data)
   data_options <- attr(data, "eyetrackingR")$data_options
+  colname_symbols <- purrr::map(data_options[grep(names(data_options), pattern="column$")], as.name) 
   if (is.null(data_options)) {
     stop("It appears your dataframe doesn't have information that eyetrackingR needs. ",
          "Did you run `make_eyetracking_r` data on it originally?",
          "If so, this information has been removed. This can happen when using functions that ",
          "transform your data significantly, like dplyr::summarise or dplyr::select.")
   }
-  time_col <- as.name(data_options$time_column)
-  ppt_col <- as.name(data_options$participant_column)
-  trial_col <- as.name(data_options$trial_column)
   if (!(rezero | remove)) stop("If both 'rezero' and 'remove' are FALSE, then this function doesn't do anything!")
   
   # Which method?
-  start_method_num <- !(sapply(list(window_start_msg, window_start_col, window_start_time), is.null))
-  stop_method_num <- !(sapply(list(window_end_msg, window_end_col, window_end_time), is.null))
+  start_method_num <- !purrr::map_lgl( list(window_start_msg, window_start_col, window_start_time), is.null )
+  stop_method_num <- !purrr::map_lgl( list(window_end_msg, window_end_col, window_end_time), is.null )
   if ( sum(start_method_num) > 1 | sum(stop_method_num) > 1 ) {
     stop("Please use exactly one of the methods for start/stop time (msg, column, or time).")
   }
@@ -371,22 +366,17 @@ subset_by_window <- function(data,
   }
   if (which(start_method_num) == 1) {
     # Message:
+    if (!is.character(msg_col)) stop("Please enter a column name for the message column (in quotes).", call. = FALSE)
     data[[msg_col]] <- as.character(data[[msg_col]])
-    if (!is.character(msg_col)) stop("Please enter a column name for the message column (in quotes).")
-    data <- group_by_(.data = data,
-                      .dots = list(data_options$participant_column, data_options$trial_column
-                      ))
-    data <- mutate_(data, 
-                    .dots = list(.WindowStart = interp(~.safe_msg_checker(MSG_COL, START_MSG, TIME_COL, PPT_COL, TRIAL_COL), 
-                                                       MSG_COL = as.name(msg_col), 
-                                                       START_MSG = window_start_msg,
-                                                       TIME_COL = time_col,
-                                                       PPT_COL = ppt_col,
-                                                       TRIAL_COL = trial_col)
-                                                       
-                    ))
+    data <- group_by_at(.tbl = data, .vars = c(data_options$participant_column, data_options$trial_column))
+    data <- mutate(.data = data, 
+                   .WindowStart = .safe_msg_checker(msg_vec = !!as.name(msg_col),
+                                                    msg = window_start_msg,
+                                                    time_vec = !!colname_symbols$time_column,
+                                                    ppt_vec = !!colname_symbols$participant_column,
+                                                    trial_vec = !!colname_symbols$trial_column )
+    )
     data <- ungroup(data)
-    data$.WindowStart[which(is.infinite(data$.WindowStart))] <- NA # see note above
   } else if (which(start_method_num) == 2) {
     # Column:
     data$.WindowStart <- data[[window_start_col]]
@@ -402,21 +392,17 @@ subset_by_window <- function(data,
   }
   if (which(stop_method_num) == 1) {
     # Message:
+    if (!is.character(msg_col)) stop("Please enter a column name for the message column (in quotes).", call. = FALSE)
     data[[msg_col]] <- as.character(data[[msg_col]])
-    if (!is.character(msg_col)) stop("Please enter a column name for the message column (in quotes).")
-    data <- group_by_(.data = data,
-                      .dots = list(data_options$participant_column, data_options$trial_column
-                      ))
-    data <- mutate_(data, 
-                    .dots = list(.WindowEnd   = interp(~.safe_msg_checker(MSG_COL, STOP_MSG, TIME_COL, PPT_COL, TRIAL_COL), 
-                                                       MSG_COL = as.name(msg_col), 
-                                                       STOP_MSG = window_end_msg,
-                                                       TIME_COL = time_col,
-                                                       PPT_COL = ppt_col,
-                                                       TRIAL_COL = trial_col)
-                    ))
+    data <- group_by_at(.tbl = data, .vars = c(data_options$participant_column, data_options$trial_column))
+    data <- mutate(.data = data, 
+                   .WindowEnd = .safe_msg_checker(msg_vec = !!as.name(msg_col),
+                                                  msg = window_end_msg,
+                                                  time_vec = !!colname_symbols$time_column,
+                                                  ppt_vec = !!colname_symbols$participant_column,
+                                                  trial_vec = !!colname_symbols$trial_column )
+    )
     data <- ungroup(data)
-    data$.WindowEnd[which(is.infinite(data$.WindowEnd))] <- NA # see note above
   } else if (which(stop_method_num) == 2) {
     # Column:
     data$.WindowEnd <- data[[window_end_col]]
@@ -435,28 +421,24 @@ subset_by_window <- function(data,
   df_subsetted <- filter(.data = data,
                          !is.na(.WindowEnd),
                          !is.na(.WindowStart))
+  
   if (remove) {
-    df_subsetted <- filter_(.data = df_subsetted,
-                          .dots = list(interp(~TIME_COL >= .WindowStart & TIME_COL < .WindowEnd, TIME_COL = time_col)))
+    after_start <- df_subsetted[[data_options$time_column]] >= df_subsetted$.WindowStart
+    before_end <- df_subsetted[[data_options$time_column]] < df_subsetted$.WindowEnd
+    df_subsetted <- df_subsetted[which(after_start&before_end), , drop=FALSE]
   } 
   
   # Rezero
   if (rezero) {
-    df_grouped <- group_by_(.data = df_subsetted,
-                            .dots = list(data_options$participant_column, data_options$trial_column
-                            ))
-    df_rezeroed <- mutate_(.data = df_grouped,
-                           .dots = list(.NewTimeStamp = interp(~TIME_COL - .WindowStart, TIME_COL = time_col))
-                           )
+    df_grouped <- group_by_at(df_subsetted, .vars = c(data_options$participant_column, data_options$trial_column))
+    df_rezeroed <- mutate(.data = df_grouped, 
+                          !!colname_symbols$time_column := (!!colname_symbols$time_column) - .WindowStart)
     out <- ungroup(df_rezeroed)
-    out[[data_options$time_column]] <- out[[".NewTimeStamp"]]
-    out[[".NewTimeStamp"]] <- NULL
   } else {
     out <- df_subsetted
   }
 
-  out[[".WindowStart"]] <- NULL
-  out[[".WindowEnd"]] <- NULL
+  out <- select(out, -.WindowStart, -.WindowEnd)
   
   attr(out, "eyetrackingR") <- list(data_options = data_options)
   class(out) <- orig_classes
@@ -496,25 +478,24 @@ trackloss_analysis <- function(data) {
          "transform your data significantly, like dplyr::summarise or dplyr::select.")
   }
   
-  trackloss_col <- as.name(data_options$trackloss_column)
-
+  colname_symbols <- purrr::map(data_options[grep(names(data_options), pattern="column$")], as.name) 
+  
   # Get Trackloss-by-Trial:
-  df_grouped_trial <- group_by_(data, .dots = list(data_options$participant_column, data_options$trial_column))
-  df_trackloss_by_trial <- mutate_(df_grouped_trial,
-                                   .dots = list(SumTracklossForTrial = interp(~sum(TRACKLOSS_COL, na.rm = TRUE), TRACKLOSS_COL = trackloss_col),
-                                                TotalTrialLength = interp(~length(TRACKLOSS_COL), TRACKLOSS_COL = trackloss_col),
-                                                TracklossForTrial = interp(~SumTracklossForTrial/TotalTrialLength)
-                                   ))
-
+  df_grouped_trial <- group_by_at(.tbl = data, .vars = c(data_options$participant_column, data_options$trial_column))
+  df_trackloss_by_trial <- mutate(.data = df_grouped_trial, 
+                                  SumTracklossForTrial = sum(!!colname_symbols$trackloss_column, na.rm = TRUE),
+                                  TotalTrialLength = n(),
+                                  TracklossForTrial = SumTracklossForTrial/TotalTrialLength)
+  
   # Get Trackloss-by-Participant:
-  df_grouped_ppt <- group_by_(df_trackloss_by_trial, .dots = list(data_options$participant_column))
-  df_trackloss_by_ppt <- mutate_(df_grouped_ppt,
-                                 .dots = list(SumTracklossForParticipant = interp(~sum(TRACKLOSS_COL, na.rm = TRUE), TRACKLOSS_COL = trackloss_col),
-                                              TotalParticipantLength = interp(~length(TRACKLOSS_COL), TRACKLOSS_COL = trackloss_col),
-                                              TracklossForParticipant = interp(~SumTracklossForParticipant/TotalParticipantLength)))
+  df_grouped_ppt <- group_by_at(.tbl = df_trackloss_by_trial, .vars = c(data_options$participant_column))
+  df_trackloss_by_ppt <- mutate(df_grouped_ppt,
+                                SumTracklossForParticipant = sum(!!colname_symbols$trackloss_column, na.rm = TRUE),
+                                TotalParticipantLength = n(),
+                                TracklossForParticipant = SumTracklossForParticipant/TotalParticipantLength)
 
   # Get Z-Scores:
-  df_grouped <- group_by_(df_trackloss_by_ppt, .dots = list(data_options$participant_column, data_options$trial_column))
+  df_grouped <- group_by_at(df_trackloss_by_ppt, .vars = c(data_options$participant_column, data_options$trial_column))
   df_summarized <- summarize(df_grouped,
                              Samples = mean(TotalTrialLength, na.rm = TRUE),
                              TracklossSamples = mean(SumTracklossForTrial, na.rm = TRUE),
@@ -568,10 +549,10 @@ trackloss_analysis <- function(data) {
 #' @export
 #' @return Cleaned data
 clean_by_trackloss <- function(data,
-                              participant_prop_thresh = 1,
-                              trial_prop_thresh = 1,
-                              window_start_time = -Inf, window_end_time = Inf) {
-
+                               participant_prop_thresh = 1,
+                               trial_prop_thresh = 1,
+                               window_start_time = -Inf, window_end_time = Inf) {
+  
   data_options <- attr(data, "eyetrackingR")$data_options
   if (is.null(data_options)) {
     stop("It appears your dataframe doesn't have information that eyetrackingR needs. ",
@@ -627,6 +608,7 @@ clean_by_trackloss <- function(data,
 #' @param describe_column The column to return descriptive statistics about.
 #' @param group_columns Any columns to group by when calculating descriptive statistics (e.g., participants,
 #'  conditions, etc.)
+#' @param quantiles Numeric vector of length two with quantiles to compute (default: \code{c(.025, .975)}).
 #'  
 #'
 #' @examples 
@@ -644,7 +626,7 @@ clean_by_trackloss <- function(data,
 #' @export
 #' @return A dataframe giving descriptive statistics for the \code{describe_column}, including mean, SD, var,
 #' min, max, and number of trials
-describe_data <- function(data, describe_column, group_columns) {
+describe_data <- function(data, describe_column, group_columns, quantiles = c(.025, .975)) {
 
   # Data options:
   data_options <- attr(data, "eyetrackingR")$data_options
@@ -654,27 +636,28 @@ describe_data <- function(data, describe_column, group_columns) {
          "If so, this information has been removed. This can happen when using functions that ",
          "transform your data significantly, like dplyr::summarise or dplyr::select.")
   }
-  
-  # Build Summarize Expression
-  summarize_expr <- list(Mean = interp( ~mean(DV_COL, na.rm=TRUE),  DV_COL = as.name(describe_column) ),
-                       SD   = interp( ~sd(DV_COL, na.rm=TRUE),      DV_COL = as.name(describe_column) ),
-                       Var  = interp( ~var(DV_COL, na.rm=TRUE),     DV_COL = as.name(describe_column) ),
-                       Min  = interp( ~min(DV_COL, na.rm=TRUE)*1.0, DV_COL = as.name(describe_column) ),
-                       Max  = interp( ~max(DV_COL, na.rm=TRUE)*1.0, DV_COL = as.name(describe_column) ),
-                       N    = ~ n()
-  )
-  if (data_options$trial_column %in% colnames(data)) {
-    summarize_expr$NumTrials = interp( ~n_distinct(TRIAL_COL), TRIAL_COL = as.name(data_options$trial_column))
-  }
 
   # Group, Summarize
-  df_grouped <- group_by_(data, .dots = as.list(group_columns))
-  df_summarized <- summarize_(df_grouped, .dots =summarize_expr )
-  class(df_summarized) <- c("eyetrackingR_data_summary", class(df_summarized))
-  attr(df_summarized, "eyetrackingR") <- list(data_options = data_options, 
-                                             describe_column = describe_column,
-                                             group_columns = group_columns)
-  return(df_summarized)
+  dc_sym <- as.name(describe_column)
+  df_grouped <- group_by_at(data, .vars = group_columns)
+  df_summarized <- summarize(df_grouped,
+                             Mean = mean(!!dc_sym, na.rm=TRUE),
+                             SD = sd(!!dc_sym, na.rm=TRUE),
+                             LowerQ = quantile(!!dc_sym, probs = quantiles[1], na.rm = TRUE),
+                             UpperQ = quantile(!!dc_sym, probs = quantiles[2], na.rm = TRUE),
+                             Min = min(!!dc_sym, na.rm=TRUE),
+                             Max = max(!!dc_sym, na.rm=TRUE),
+                             N = n() )
+  if (data_options$trial_column %in% colnames(data))
+    df_summarized <- left_join(x = df_summarized, 
+                               y = summarize(df_grouped, NumTrials = n_distinct(!!as.name(data_options$trial_column), na.rm = TRUE)),
+                               by = group_columns)
+  out <- ungroup(df_summarized)
+  class(out) <- c("eyetrackingR_data_summary", class(out))
+  attr(out, "eyetrackingR") <- list(data_options = data_options, 
+                                    describe_column = describe_column,
+                                    group_columns = group_columns)
+  return(out)
 
 }
 
@@ -689,8 +672,13 @@ describe_data <- function(data, describe_column, group_columns) {
 #' @return A ggplot object
 plot.eyetrackingR_data_summary <- function(x, ...) {
   attrs <- attr(x, "eyetrackingR")
-  
-  ggplot(x, aes_string(x=attrs$group_columns[1], y="Mean", group=attrs$group_columns[2])) +
+  if (length(attrs$group_columns) > 1) group_col <- attrs$group_columns[2]
+  else group_col <- NULL
+  g <- ggplot(x, aes_string(x=attrs$group_columns[1], y="Mean", group=group_col)) +
     stat_summary(fun.y='mean', geom='point') +
-    stat_summary(fun.y='mean', geom='line')
+    theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
+    scale_y_continuous(attrs$describe_column)
+  if (!is.null(group_col))
+    g <- g + stat_summary(fun.y='mean', geom='line') 
+  return(g)
 }
